@@ -1,4 +1,5 @@
-nntsestimationSymmetric <- function (M = 0, data, maxit = 500) 
+nntsestimationSymmetric<-
+function (M = 0, data, maxit = 500) 
 {
     if (M == 0) 
         return("Uniform distribution: no parameters to estimate")
